<?php

////////////////////////////////////////////////
////// ADD NEW BOX /////////////////////////////
////////////////////////////////////////////////

function nb_add_box() {
	if(!isset($_POST['lcwp_nonce']) || !wp_verify_nonce($_POST['lcwp_nonce'], 'lcwp_nonce')) {wp_die('Cheating?');};
	if(!isset($_POST['nb_name'])) {wp_die('data is missing');}
	$name = $_POST['nb_name'];
	
	// default checkbox values
	$default = serialize(array(
		'src'=>array(), 
		'settings'=>array(
			'expandable_news' => 1,
			'scroll_exp_elem' => 1,
			'manage_exp_images' => 1,
		)
	));
	$resp = wp_insert_term($name, 'nb_boxes', array('description'=>$default));
	
	if(is_array($resp)) {wp_die('success');}
	else {
		$err_mes = $resp->errors['term_exists'][0];
		wp_die($err_mes);
	}
}
add_action('wp_ajax_nb_add_box', 'nb_add_box');




/////////////////////////////////////////////
////// LOAD BOXES LIST //////////////////////
/////////////////////////////////////////////

function nb_boxes_list() {
	if(!isset($_POST['lcwp_nonce']) || !wp_verify_nonce($_POST['lcwp_nonce'], 'lcwp_nonce')) {wp_die('Cheating?');};
	//if(!isset($_POST['nb_page']) || !filter_var($_POST['nb_page'], FILTER_VALIDATE_INT)) {$pag = 1;}
	
	$pag = 1;
	$per_page = 100;
	
	// search
	$search = (isset($_POST['box_src'])) ? $_POST['box_src']: '';
	$src_string = (!empty($search)) ? '&search='.$search : '';	
	
	// get all terms 
	$grids = get_terms('nb_boxes', 'hide_empty=0'.$src_string);
	$total = count($grids);
	
	$tot_pag = ceil( $total / $per_page );
	
	
	if($pag > $tot_pag) {$pag = $tot_pag;}
	$offset = ($pag - 1) * $per_page;
	
	// get page terms
	$args =  array(
		'number' => $per_page,
		'offset' => $offset,
		'hide_empty' => 0
	);
	if($src_string != '') {
		$args['search'] = $search;	
	}
	$items = get_terms('nb_boxes', $args);

	// clean term array
	$clean_elems = array();
	
	foreach ( $items as $item ) {
		$clean_elems[] = array('id' => $item->term_id, 'name' => $item->name);
	}
	
	$to_return = array(
		'elems' => $clean_elems,
		'pag' => $pag, 
		'tot_pag' => $tot_pag
	);
    
	echo json_encode($to_return);
	wp_die();
}
add_action('wp_ajax_nb_boxes_list', 'nb_boxes_list');




//////////////////////////////////////////
////// CLONE BOX /////////////////////////
//////////////////////////////////////////

function nb_clone_box() {
	if(!isset($_POST['lcwp_nonce']) || !wp_verify_nonce($_POST['lcwp_nonce'], 'lcwp_nonce')) {wp_die('Cheating?');};
	if(!isset($_POST['box_id']) || !isset($_POST['new_name']) || empty($_POST['new_name'])) {wp_die('data is missing');}
	
	require_once(NB_DIR . '/functions.php');
	
	$box_id = (int)$_POST['box_id'];
	$name = $_POST['new_name'];
	
	
	$box = get_term($box_id, 'nb_boxes');
	if(empty($box) || !is_object($box) || is_wp_error($box)) {
		wp_die( __('Source box not found', 'nb_ml') );	
	}
	$data = $box->description;
	
		
	$resp = wp_insert_term($name, 'nb_boxes', array(
		'slug' 			=> uniqid(), 
		'description'	=> $data
	));
	
	if(is_wp_error($resp)) {
		echo $resp->get_error_message();
		wp_die();
	} 
	else {	
		wp_die('success');
	}
}
add_action('wp_ajax_nb_clone_box', 'nb_clone_box');



//////////////////////////////////////////
////// RENAME BOX ////////////////////////
//////////////////////////////////////////

function nb_rename_box() {
	if(!isset($_POST['lcwp_nonce']) || !wp_verify_nonce($_POST['lcwp_nonce'], 'lcwp_nonce')) {wp_die('Cheating?');};
	if(!isset($_POST['box_id']) || !isset($_POST['new_name']) || empty($_POST['new_name'])) {wp_die('data is missing');}

	$box_id = (int)$_POST['box_id'];
	$name = $_POST['new_name'];
	
	
	// check if name is already taken
	$check = get_term_by('name', $name, 'nb_boxes');
	if($check && $check->term_id != $box_id) {
		wp_die( __('Another box has this name', 'nb_ml') );	
	}

	// update
	$args = array(
  		'name' => $name,
	);
	$resp = wp_update_term($box_id, 'nb_boxes', $args);
	
	if(is_wp_error($resp)) {
		echo $resp->get_error_message();
		wp_die();
	} 
	else {	
		wp_die('success');
	}
}
add_action('wp_ajax_nb_rename_box', 'nb_rename_box');



////////////////////////////////////////////////
////// DELETE BOX //////////////////////////////
////////////////////////////////////////////////

function nb_del_box() {
	if(!isset($_POST['lcwp_nonce']) || !wp_verify_nonce($_POST['lcwp_nonce'], 'lcwp_nonce')) {wp_die('Cheating?');};
	if(!isset($_POST['box_id'])) {wp_die('data is missing');}
	$id = addslashes($_POST['box_id']);
	
	$resp = wp_delete_term($id, 'nb_boxes');

	if($resp == '1') {wp_die('success');}
	else {wp_die('error during box deletion');}
}
add_action('wp_ajax_nb_del_box', 'nb_del_box');




////////////////////////////////////////////////
////// DISPLAY BOX BUILDER /////////////////////
////////////////////////////////////////////////

function nl_box_builder() {
	require_once(NB_DIR . '/functions.php');
	
	if(!isset($_POST['box_id'])) {wp_die('data is missing');}
	$box_id = addslashes($_POST['box_id']);

	// get term and unserialize contents
	$box = get_term($box_id, 'nb_boxes');
	$data = (empty($box->description)) ? '' : unserialize( nb_fix_serialization($box->description)); // eventually fix serialization errors
	
	// v1.30 - added json_encode - process it
	if($data && !is_array($data)) {
		$data = json_decode(base64_decode($data), true);
	}
	
	// still no array - return defaults
	if(!is_array($data)) {
		$data = array('src'=>array(), 'settings'=>array());
	}
	?>
    <form class="form-wrap" id="nb_box_opts">  
		<div class="postbox">
          <h3 class="hndle"><?php _e('News Sources', 'nb_ml') ?></h3>
          <div class="inside">
        
            <div class="lcwp_mainbox_meta">
				<div class="nb_add_src">
                	<?php _e('Add new source', 'nb_ml') ?> 
                    <select name="nb_news_source" autocomplete="off">
                    	<?php 
						foreach(nb_news_sources() as $k => $v) {
							echo '<option value="'. esc_attr($k) .'">'. esc_html($v) .'</option>';	
						}
						?>
                    </select>
                    <input type="button" name="nb_addd_source" class="button-secondary" value="<?php esc_attr_e('Add', 'nb_ml') ?>" />
                </div>
                <div class="nb_sources">
                	<?php 
					// saved sources
					foreach($data['src'] as $src) {
						$cpt_src = (strpos($src['src_type'], '|||') !== false) ? 'nb_cpt_src' : '';
						
						echo '
						<div class="nb_type_block nb_'.$src['src_type'].'_src '.$cpt_src.'">
						<h4>
							'. nb_news_sources($src['src_type']) .' 
							<div class="nb_cmd"><span class="lcwp_del_row"></span></div>
						</h4>';
					
						echo nb_src_form_block($src) . '<div class="mgom_btm_border_fix"></div></div>';
					}
					?>
                </div>
            </div>  
          </div>
        </div>
        
        <br/>
        
        <div class="postbox" id="nb_box_settings">
          <h3 class="hndle"><?php _e('Settings', 'nb_ml') ?></h3>
          <div class="inside">
            <div class="lcwp_mainbox_meta">
            	
                <div class="nb_type_block">
                    <h4><?php _e('Initial mode', 'nb_ml') ?></h4>
                    
                    <?php
					$fields = array('max_news', 'news_per_time', 'only_w_images', 'height', 'layout', 'boxed_news', 'horiz_img_mode', 'buttons_position', 'hide_elements', 'horiz_img_h', 'vert_img_w', 'title_behavior', 'img_behavior', 'date_format', 'elapsed_time', 'read_more_btn', 'read_more_btn_txt');
                    foreach($fields as $field) {
                        $val = (isset($data['settings'][$field])) ? $data['settings'][$field] : ''; 
                        echo nb_fields_builder($field, $val);
                    }
                    ?>
                
                	<div class="mgom_btm_border_fix"></div>
            	</div>
                
                <div class="nb_type_block">
                    <h4><?php _e('Expanded mode', 'nb_ml') ?></h4>
                    
                    <?php
					//$fields = array('expandable_news', 'scroll_exp_elem', 'exp_main_img_pos', 'manage_exp_images', 'exp_img_w', 'exp_img_h');
					$fields = array('expandable_news', 'scroll_exp_elem', 'manage_exp_images');
                    foreach($fields as $field) {
                        $val = (isset($data['settings'][$field])) ? $data['settings'][$field] : ''; 
                        echo nb_fields_builder($field, $val);
                    }
                    ?>
                
                	<div class="mgom_btm_border_fix"></div>
            	</div>
                
                <div class="nb_type_block">
                    <h4><?php _e('Navigation / slideshow', 'nb_ml') ?></h4>
                    
                    <?php
					$fields = array('nav_arrows', 'carousel', 'autoplay', 'animation_time', 'slideshow_time', 'pause_on_hover', 'slide_all', 'autop_after_exp');
                    foreach($fields as $field) {
                        $val = (isset($data['settings'][$field])) ? $data['settings'][$field] : ''; 
                        echo nb_fields_builder($field, $val);
                    }
                    ?>
                
                	<div class="mgom_btm_border_fix"></div>
            	</div>
                
            </div>  
          </div>
        </div>
    </form>    
	<?php
	wp_die();
}
add_action('wp_ajax_nl_box_builder', 'nl_box_builder');




////////////////////////////////////////////////
////// ADD NEWS SOURCE /////////////////////////
////////////////////////////////////////////////

function nb_add_src() {
	require_once(NB_DIR . '/functions.php');
	
	if(!isset($_POST['nb_type'])) {wp_die('data is missing');}
	$type = addslashes($_POST['nb_type']);
	
	echo '
	<div class="nb_type_block nb_'.$type.'_src">
	<h4>
		'. nb_news_sources($type) .' 
		<div class="nb_cmd"><span class="lcwp_del_row"></span></div>
	</h4>';

	echo nb_src_form_block(array('src_type' => $type)) . '<div class="mgom_btm_border_fix"></div></div>';
	wp_die();
}
add_action('wp_ajax_nb_add_src', 'nb_add_src');




////////////////////////////////////////////////
////// SAVE BOX ////////////////////////////////
////////////////////////////////////////////////

function nb_save_box() {
	include_once(NB_DIR . '/functions.php');
	include_once(NB_DIR . '/classes/simple_form_validator.php');		
		
		$validator = new simple_fv;
		$indexes = array();
		
		// sources
		$indexes[] = array('index'=>'box_id', 'label'=>__('Box ID', 'nb_ml'), 'required'=>true, 'type'=>'int');
		$indexes[] = array('index'=>'max_news', 'label'=>__('News to keep', 'nb_ml'), 'required'=>true, 'type'=>'int', 'min_val'=>1, 'max_val'=>40);
		$indexes[] = array('index'=>'news_per_time', 'label'=>__('News per time', 'nb_ml'), 'required'=>true, 'type'=>'int', 'min_val'=>1, 'max_val'=>15);
		$indexes[] = array('index'=>'only_w_images', 'label'=>"Keep only news with images?");
		$indexes[] = array('index'=>'height', 'label'=>__('Box height', 'nb_ml'), 'required'=>true, 'type'=>'int');
		$indexes[] = array('index'=>'layout', 'label'=>'Box main layout');
		$indexes[] = array('index'=>'boxed_news', 'label'=>"Boxed style?");
		$indexes[] = array('index'=>'horiz_img_mode', 'label'=>"Horiz image mode?");
		$indexes[] = array('index'=>'buttons_position', 'label'=>"Buttons position");
		$indexes[] = array('index'=>'hide_elements', 'label'=>"Global elements to hide");
		$indexes[] = array('index'=>'btn_over_img', 'label'=>"Side buttons over image?");
		$indexes[] = array('index'=>'show_src_logo', 'label'=>"Show news source logo?");
		$indexes[] = array('index'=>'horiz_img_h', 'label'=>__("Image's height <small>(for horizontal layout)</small>", 'nb_ml'), 'type'=>'int');
		$indexes[] = array('index'=>'vert_img_w', 'label'=>__("Image's width <small>(for vertical layout)</small>", 'nb_ml'), 'type'=>'int');
		$indexes[] = array('index'=>'title_behavior', 'label'=>"News title behavior");
		$indexes[] = array('index'=>'img_behavior', 'label'=>"Main image behavior");
		$indexes[] = array('index'=>'date_format', 'label'=>__('Date format', 'nb_ml'), 'required'=>true);
		$indexes[] = array('index'=>'elapsed_time', 'label'=>"Use elapsed time?");
		$indexes[] = array('index'=>'read_more_btn', 'label'=>'Replace date with "read more" button?');
		$indexes[] = array('index'=>'read_more_btn_txt', 'label'=>__('"Read more"', 'nb_ml').' '. __("button's text", 'nb_ml'));
		
		$indexes[] = array('index'=>'expandable_news', 'label'=>"Expandable news?");
		$indexes[] = array('index'=>'scroll_exp_elem', 'label'=>"Keep close button and side image visible on scroll?");
		//$indexes[] = array('index'=>'exp_main_img_pos', 'label'=>"Main image position");
		$indexes[] = array('index'=>'manage_exp_images', 'label'=>"Manage news images?");
		//$indexes[] = array('index'=>'exp_img_w', 'label'=>"Image's container width");
		//$indexes[] = array('index'=>'height', 'label'=>__("Image's container width", 'nb_ml'), 'required'=>true);
		
		$indexes[] = array('index'=>'nav_arrows', 'label'=>"Navigation arrows position");
		$indexes[] = array('index'=>'carousel', 'label'=>'Carousel mode?');
		$indexes[] = array('index'=>'animation_time', 'label'=>__("Animation time", 'nb_ml'), 'required'=>true, 'type'=>'int');
		$indexes[] = array('index'=>'autoplay', 'label'=>'Autoplay slideshow?');
		$indexes[] = array('index'=>'slideshow_time', 'label'=>__("Slideshow interval", 'nb_ml'), 'required'=>true, 'type'=>'int');
		$indexes[] = array('index'=>'pause_on_hover', 'label'=>'Pause on hover?');
		$indexes[] = array('index'=>'slide_all', 'label'=>'Slide all visible elements?');
		$indexes[] = array('index'=>'autop_after_exp', 'label'=>'Resume autoplay after expanded news closing?');
		
		$validator->formHandle($indexes);
		$fdata = $validator->form_val;
		$error = $validator->getErrors();
		
		if($error) {wp_die('<div class="error"><p>'.$error.'</p></div>');}
		else {
			// sources
			$sources = array();
			$sources_data = json_decode(rawurldecode(stripslashes($_POST['src_data'])));
			
			if(!is_array($sources_data) || count($sources_data) == 0) {_e('A news source is needed', 'nb_ml'); wp_die();}
			
			foreach($sources_data as $src) {
				$sources[] = nb_serArr_to_php($src);	
			}
			
			// clean settings
			foreach($fdata as $key=>$val) {
				if(!is_array($val)) {
					$fdata[$key] = stripslashes($val);
				} else {
					$fdata[$key] = array();
					foreach($val as $arr_val) {$fdata[$key][] = stripslashes($arr_val);}
				}
			}
			
			// wrap up elements 
			$box_data = array(
				'src' 		=> $sources,
				'settings' 	=> $fdata 
			); 

			// prepare to be saved - safe way to avoid serialization troubles
			$box_data = base64_encode(json_encode($box_data));

			// save
			$result = wp_update_term($fdata['box_id'], 'nb_boxes', array(
				'slug' => uniqid(),
				'description' => serialize($box_data)
			));
			
			echo (is_wp_error($result)) ? $result->get_error_message() : 'success';	
		}
	wp_die();
}
add_action('wp_ajax_nb_save_box', 'nb_save_box');